﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Olap.Data;
using Infragistics.Controls.Grids;
using Infragistics.Olap.FlatData;
using Infragistics.Olap.Xmla;

namespace HiddenExpansionIndicatorXPG
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(MainWindow_Loaded);
        }
        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            this.LoadPivotGridWithSampleData();

        }


        List<PartnerPercentage> myList;

        private void LoadPivotGridWithSampleData()
        {
            try
            {


                myList = new List<PartnerPercentage>();
                myList.Add(new PartnerPercentage { Partner = "P", Percentage = 100 });
                for (int i = 0; i < 100; i++)
                    myList.Add(new PartnerPercentage { Investment = "inv " + i, Partner = "P" + i, Percentage = i * 100 });

                FlatDataSource flatDataSource = new FlatDataSource
                {
                    ItemsSource = myList,
                    Cube = XmlaDataSource.GenerateInitialCube("PartnerPercentage"),
                    Columns = XmlaDataSource.GenerateInitialItems("[Partner].[Partner]"),
                    Rows = XmlaDataSource.GenerateInitialItems("[Investment].[Investment]"),
                    // Columns = XmlaDataSource.GenerateInitialItems("[Investment]{[Investment].&amp[Yangtze Special Situations Fund]}"),
                    Measures = XmlaDataSource.GenerateInitialItems("Percentage"),



                };

                CubeMetadata cubeMetadata = new CubeMetadata();
                cubeMetadata.DisplayName = "Partner Percentage Matrix";
                cubeMetadata.DataTypeFullName = typeof(PartnerPercentage).FullName;
                cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
                {
                    SourcePropertyName = "Percentage",
                    DisplayName = "Percentage",
                    DisplayFormat = "{0:P4}"
                });

                cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
                {
                    SourcePropertyName = "Partner",
                    DisplayName = "Partner"
                });

                flatDataSource.CubesSettings.Add(cubeMetadata);

                // Define hierarchies
                HierarchyDescriptor<PartnerPercentage> partnerHierarchy = new HierarchyDescriptor<PartnerPercentage>(p => p.Partner);
                partnerHierarchy.AddLevel(p =>
                    "All partners",
                    "All partners"
                    );
                partnerHierarchy.AddLevel(p =>
                    p.Partner,
                    "Partner name"
                    );
                flatDataSource.AddHierarchyDescriptor(partnerHierarchy);

                HierarchyDescriptor<PartnerPercentage> investmentHierarchy = new HierarchyDescriptor<PartnerPercentage>(p => p.Investment);
                investmentHierarchy.AddLevel(p =>
                    "All investments",
                    "All investments"
                    );
                investmentHierarchy.AddLevel(p =>
                    p.Investment,
                    "Investment name"
                    );
                flatDataSource.AddHierarchyDescriptor(investmentHierarchy);

                this.pivotGrid.DataSource = flatDataSource;
                this.dataSelector.DataSource = flatDataSource;

                this.pivotGrid.DataSource.ResultChanged += new EventHandler<System.ComponentModel.AsyncCompletedEventArgs>(DataSource_ResultChanged);

            }
            catch (Exception ex)
            {
                MessageBox.Show("LoadPivotGridWithSampleData - " + ex.Message);
            }

        }

        void DataSource_ResultChanged(object sender, System.ComponentModel.AsyncCompletedEventArgs e)
        {

            foreach (IMember m in pivotGrid.DataSource.Result.RowAxis.Tuples[0].Members[0].Members)
                if (m.Caption == "N/A")
                {
                    IMember currentMemeber = pivotGrid.DataSource.Result.RowAxis.Tuples[0].Members[0];
                    (pivotGrid.GridLayout.RowHeaderCells.Where(c => c.Member == currentMemeber).First() as PivotHeaderCell).Style = Application.Current.Resources["RowStyle"] as Style;
                }
        }
    }
    public class PartnerPercentage
    {
        public string Investment { get; set; }
        public string Partner { get; set; }
        public double Percentage { get; set; }
    }
}
